==> zio-aws-apigatewaymanagementapi_2.12-5.17.104.10-sources.jar: zio/aws/apigatewaymanagementapi/model/Identity.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class Identity(sourceIp: __string, userAgent: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity = {
    import Identity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
      .builder()
      .sourceIp(__string.unwrap(sourceIp): java.lang.String)
      .userAgent(__string.unwrap(userAgent): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.Identity.wrap(buildAwsValue())
}
object Identity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewaymanagementapi.model.Identity =
      zio.aws.apigatewaymanagementapi.model.Identity(sourceIp, userAgent)
    def sourceIp: __string
    def userAgent: __string
    def getSourceIp: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceIp)
    def getUserAgent: ZIO[Any, Nothing, __string] = ZIO.succeed(userAgent)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ) extends zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly {
    override val sourceIp: __string =
      zio.aws.apigatewaymanagementapi.model.primitives.__string(impl.sourceIp())
    override val userAgent: __string =
      zio.aws.apigatewaymanagementapi.model.primitives
        .__string(impl.userAgent())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ): zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly = new Wrapper(impl)
}

==> zio-aws-apigatewaymanagementapi_2.12-5.17.161.1-sources.jar: zio/aws/apigatewaymanagementapi/model/Identity.scala <==
package zio.aws.apigatewaymanagementapi.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.apigatewaymanagementapi.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class Identity(sourceIp: __string, userAgent: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity = {
    import Identity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
      .builder()
      .sourceIp(sourceIp: java.lang.String)
      .userAgent(userAgent: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly =
    zio.aws.apigatewaymanagementapi.model.Identity.wrap(buildAwsValue())
}
object Identity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewaymanagementapi.model.Identity =
      zio.aws.apigatewaymanagementapi.model.Identity(sourceIp, userAgent)
    def sourceIp: __string
    def userAgent: __string
    def getSourceIp: ZIO[Any, Nothing, __string] = ZIO.succeed(sourceIp)
    def getUserAgent: ZIO[Any, Nothing, __string] = ZIO.succeed(userAgent)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ) extends zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly {
    override val sourceIp: __string = impl.sourceIp(): __string
    override val userAgent: __string = impl.userAgent(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewaymanagementapi.model.Identity
  ): zio.aws.apigatewaymanagementapi.model.Identity.ReadOnly = new Wrapper(impl)
}
